/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.gatein.common.xml.stax.writer.builder;

import java.io.OutputStream;
import java.io.Writer;

import javax.xml.stream.XMLStreamWriter;
import javax.xml.transform.Result;

import org.gatein.common.xml.stax.writer.StaxWriter;
import org.gatein.common.xml.stax.writer.formatting.XmlStreamingFormatter;
import org.staxnav.EnumElement;
import org.staxnav.Naming;
import org.staxnav.StaxNavException;

/**
 * @author <a href="mailto:nscavell@redhat.com">Nick Scavelli</a>
 * @version $Revision$
 */
public interface StaxWriterBuilder {
    StaxWriterBuilder withProperty(String name, Object value);

    StaxWriterBuilder withPropertyIfSupported(String name, Object value);

    StaxWriterBuilder withEncoding(String encoding);

    StaxWriterBuilder withVersion(String version);

    StaxWriterBuilder withFormatting(XmlStreamingFormatter formatter);

    StaxWriterBuilder withOutputStream(OutputStream outputStream);

    StaxWriterBuilder withOutputStream(OutputStream outputStream, String encoding);

    StaxWriterBuilder withWriter(Writer writer);

    StaxWriterBuilder withResult(Result result);

    StaxWriterBuilder withXmlStreamWriter(XMLStreamWriter writer);

    <N> StaxWriter<N> build(Naming<N> naming) throws StaxNavException, IllegalStateException;

    <E extends Enum<E> & EnumElement<E>> StaxWriter<E> build(Class<E> enumeratedType) throws StaxNavException,
            IllegalStateException;
}
